==> haskell-comonad-5.0.8-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 comonad
version:              5.0.8
visibility:           public
id:                   comonad-5.0.8-3pYj1AnsvAsDKyxRyjhP3v
key:                  comonad-5.0.8-3pYj1AnsvAsDKyxRyjhP3v
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  dfacb363f7585e0b6afc8bc8d44d4bff
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.0.1/site-local/comonad-5.0.8
library-dirs:         /usr/lib/ghc-9.0.1/site-local/comonad-5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/comonad-5.0.8
hs-libraries:         HScomonad-5.0.8-3pYj1AnsvAsDKyxRyjhP3v
depends:
    base-4.15.0.0 containers-0.6.4.1
    distributive-0.6.2.1-gMkXpOycpm4CH4vVEGKxs
    indexed-traversable-0.1.2-LXVxvX2Ns0jBYLb1hVs3y6
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 transformers-0.5.6.2
    transformers-compat-0.7.1-27E2wCklav6CMkj1Ns7rzE

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.8-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 comonad
version:              5.0.8
visibility:           public
id:                   comonad-5.0.8-KLyLAxsL77RIY9sRzUIx7r
key:                  comonad-5.0.8-KLyLAxsL77RIY9sRzUIx7r
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  f9f49f684000fd41cc6e088c30d939af
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.0.2/site-local/comonad-5.0.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/comonad-5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/comonad-5.0.8
hs-libraries:         HScomonad-5.0.8-KLyLAxsL77RIY9sRzUIx7r
depends:
    base-4.15.1.0 containers-0.6.4.1
    distributive-0.6.2.1-4SPuK3FbgMz4g7IeWkQbPP
    indexed-traversable-0.1.2-55rCITp0bj2K4TSTU28RrG
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR transformers-0.5.6.2
    transformers-compat-0.7.1-5G5J9BcZIFIGkjABObiUpP

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
